.. heparchy documentation master file, created by
   sphinx-quickstart on Thu Jan 13 12:21:01 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to heparchy's documentation!
====================================

.. mdinclude:: ../../README.md

.. toctree::
   :caption: API Reference
   :hidden:

   api.rst


Index
=====

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
